@@ -1,10 +1,11 @@
 // Copyright (C) 2020 ~ now Uniontech Software Technology Co.,Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "gstrecordx.h"
 #include "utils.h"
+#include "../utils/log.h"
 
 
 /**
@@ -18,11 +19,12 @@ static gboolean gstBusMessageCb(GstBus *bus, GstMessage *message, GstRecordX *gs
 {
     Q_UNUSED(bus);
     if (!message) {
+        qCWarning(dsrApp) << "Received null message from GstBus";
         return true;
     }
     switch (message->type) {
     case GST_MESSAGE_ERROR: {
-
+        qCDebug(dsrApp) << "Received error message from GstBus";
         GError *error = nullptr;
         gchar *dbg = nullptr;
         gstInterface::m_gst_message_parse_error(message, &error, &dbg);
@@ -37,6 +39,7 @@ static gboolean gstBusMessageCb(GstBus *bus, GstMessage *message, GstRecordX *gs
         break;
     }
     case GST_MESSAGE_EOS: {
+        qCInfo(dsrApp) << "Received end of stream message";
         gstInterface::m_g_main_loop_quit(gstRecord->getGloop());
         break;
     }
@@ -70,6 +73,7 @@ void GstRecordX::initMemberVariables()
 //x11协议下gstreamer录制视频
 void GstRecordX::x11GstStartRecord()
 {
+    qCInfo(dsrApp) << "Starting X11 GStreamer recording";
     QStringList arguments;
     QStringList areaList;
 
@@ -84,6 +88,9 @@ void GstRecordX::x11GstStartRecord()
              << "endy=" + QString::number(m_recordArea.y() + m_recordArea.height() - 1);
     arguments << areaList.join(" ");
 
+    qCDebug(dsrApp) << "Recording area:" << m_recordArea;
+    qCDebug(dsrApp) << "Frame rate:" << m_framerate;
+
     //设置录屏的帧率
     arguments << QString("video/x-raw, framerate=%1/1").arg(m_framerate);
     //设置视频转换器
@@ -114,6 +121,7 @@ void GstRecordX::x11GstStartRecord()
 //x11协议下gstreamer停止录制视频
 void GstRecordX::x11GstStopRecord()
 {
+    qCInfo(dsrApp) << "Stopping X11 GStreamer recording";
     if (!m_pipeline) {
         qWarning() << "wayland Gstreamer 录屏未能正常结束！录屏管道被提前释放！";
         return;
@@ -125,8 +133,14 @@ void GstRecordX::x11GstStopRecord()
 //wayland协议下gstreamer录制管道构建及启动录制视频
 void GstRecordX::waylandGstStartRecord()
 {
+    qCInfo(dsrApp) << "Starting Wayland GStreamer recording";
     QStringList wlarguments;
     wlarguments << "appsrc name=videoSrc";
+    
+    qCDebug(dsrApp) << "Board vendor type:" << m_boardVendorType;
+    qCDebug(dsrApp) << "Recording area:" << m_recordArea;
+    qCDebug(dsrApp) << "Frame rate:" << m_framerate;
+
     //此处需特别注意视频帧的格式，由于在wayland协议上，采集的画面，hw机和普通机器的像素格式有差异
     if (m_boardVendorType) {
         wlarguments << QString("video/x-raw, format=RGB, framerate=%1/1, width=%2, height=%3").arg(m_framerate).arg(m_recordArea.width()).arg(m_recordArea.height());
@@ -141,7 +155,7 @@ void GstRecordX::waylandGstStartRecord()
             qCritical() << "Error: Gstreamer's Pipeline create failure!";
             return;
         }
-        qInfo() << "Gstreamer's Pipeline create successfully!";
+        qCInfo(dsrApp) << "GStreamer pipeline created successfully";
         //添加视频相关流信息
         GstElement *videoSrc = gstInterface::m_gst_bin_get_by_name(getGstBin(m_pipeline), "videoSrc");
         gstInterface::m_g_object_set(videoSrc, "format", GST_FORMAT_TIME, NULL);
@@ -155,22 +169,23 @@ void GstRecordX::waylandGstStartRecord()
         //启动Gstreamer录屏管道
         GstStateChangeReturn ret = gstInterface::m_gst_element_set_state(m_pipeline, GST_STATE_PLAYING);
         if (ret == GST_STATE_CHANGE_FAILURE) {
-            qWarning() << "Unable to set the pipeline to the playing state. Recording is failure";
+            qCWarning(dsrApp) << "Unable to set the pipeline to the playing state. Recording failed";
             gstInterface::m_gst_object_unref(m_pipeline);
             return;
         }
         QtConcurrent::run(gstInterface::m_g_main_loop_run, m_gloop);
-        qInfo() << "(Wayland) Gstreamer's Pipeline starup successfully!";
+        qCInfo(dsrApp) << "(Wayland) GStreamer pipeline startup successful";
     } else {
-        qCritical() << "Error: Gstreamer's Pipeline create failure!";
+        qCCritical(dsrApp) << "Error: GStreamer pipeline creation failed";
     }
 }
 
 //wayland协议下gstreamer停止录制视频
 void GstRecordX::waylandGstStopRecord()
 {
+    qCInfo(dsrApp) << "Stopping Wayland GStreamer recording";
     if (!m_pipeline) {
-        qWarning() << "wayland Gstreamer 录屏未能正常结束！录屏管道被提前释放！";
+        qCWarning(dsrApp) << "Wayland GStreamer recording could not end normally! Pipeline was released early!";
         return;
     }
 
@@ -187,14 +202,14 @@ void GstRecordX::waylandGstStopRecord()
     stopPipeline();
     //发射wayland gstreamer录屏完成信号
     emit waylandGstRecrodFinish();
-    qInfo() << "wayland Gstreamer 录屏结束！";
+    qCInfo(dsrApp) << "Wayland GStreamer recording ended";
 }
 
 //wayland下写入视频帧
 bool GstRecordX::waylandWriteVideoFrame(const unsigned char *frame, const int framewidth, const int frameheight)
 {
     if (!m_pipeline) {
-        qWarning() << "wayland Gstreamer 写入视频帧失败！录屏管道未初始化！";
+        qCWarning(dsrApp) << "Wayland GStreamer failed to write video frame! Recording pipeline not initialized!";
         return false;
     }
 
@@ -205,7 +220,7 @@ bool GstRecordX::waylandWriteVideoFrame(const unsigned char *frame, const int fr
     int size = m_recordArea.width() * m_recordArea.height() * 4;
     ptr = (guint8 *)gstInterface::m_g_malloc(size * sizeof(uchar));
     if (nullptr == ptr) {
-        qWarning("GStreamerRecorder::writeFrame malloc failed!");
+        qCWarning(dsrApp) << "GStreamer writeFrame malloc failed!";
         return false;
     } else {
         GstBuffer *buffer;
@@ -297,15 +312,19 @@ void GstRecordX::setBoardVendorType(int boardVendorType)
 //创建Gstreamer录屏管道，这部分x11和wayland可共用
 bool GstRecordX::createPipeline(QStringList arguments)
 {
+    qCInfo(dsrApp) << "Creating GStreamer pipeline";
     //设置编码器
     // arguments << QString("vp8enc min_quantizer=20 max_quantizer=20 cpu-used=%1 deadline=1000000 threads=%2").arg(QThread::idealThreadCount()).arg(QThread::idealThreadCount());
     if (m_videoType == VideoType::webm) {
+        qCDebug(dsrApp) << "Using VP8 encoder for WebM";
         //vp8编码
         arguments << "vp8enc min-quantizer=1 max-quantizer=50 undershoot=95 cpu-used=5 deadline=1 static-threshold=50 error-resilient=1";
     } else if (m_videoType == VideoType::ogg) {
+        qCDebug(dsrApp) << "Using Theora encoder for OGG";
         //ogg不支持vp8编码，需使用theora编码，该编码器基于vp3,编码效率低，生成的视频容存在时长不正确的问题
         arguments << "theoraenc  bitrate=2200 drop-frames=false keyframe-auto=false keyframe-force=5 keyframe-freq=5";
     } else {
+        qCWarning(dsrApp) << "Unknown video type, defaulting to VP8 encoder";
         arguments << "vp8enc min-quantizer=1 max-quantizer=50 undershoot=95 cpu-used=5 deadline=1 static-threshold=50 error-resilient=1";
     }
     arguments << "queue";
@@ -313,6 +332,7 @@ bool GstRecordX::createPipeline(QStringList arguments)
 
     //混音模式
     if (m_audioType == AudioType::Mix) {
+        qCDebug(dsrApp) << "Configuring mixed audio pipeline";
         //为保证Gstreamer管道顺利执行，做了规避处理，遇到音频设备名称不存在的情况下，输出错误日志，不在管道命令中添加音频混流器
         if (m_sysDevcieName.isEmpty() && m_micDeviceName.isEmpty()) {
             qCritical() << "Error: The system audio device name and mic audio device name is empty in Mix audio!";
@@ -326,17 +346,21 @@ bool GstRecordX::createPipeline(QStringList arguments)
             arguments << getAudioPipeline(m_micDeviceName, "mic", "mix");
         }
     } else if (m_audioType == AudioType::Mic) { //单麦克风音频模式
+        qCDebug(dsrApp) << "Configuring microphone-only audio pipeline";
         //为保证Gstreamer管道顺利执行，做了规避处理，遇到音频设备名称不存在的情况下，输出错误日志，不在管道命令中添加音频,录制无声视频
         arguments << getAudioPipeline(m_micDeviceName, "mic", "mux");
     } else if (m_audioType == AudioType::Sys) { //单系统音频模式
+        qCDebug(dsrApp) << "Configuring system-only audio pipeline";
         //为保证Gstreamer管道顺利执行，做了规避处理，遇到音频设备名称不存在的情况下，输出错误日志，不在管道命令中添加音频,录制无声视频
         arguments << getAudioPipeline(m_sysDevcieName, "sys", "mux");
     }
 
     if (m_videoType == VideoType::webm) {
+        qCDebug(dsrApp) << "Using WebM muxer";
         //webmmux 复用器
         arguments << "webmmux name=mux";
     } else if (m_videoType == VideoType::ogg) {
+        qCDebug(dsrApp) << "Using OGG muxer";
         arguments << "oggmux name=mux";
     } else {
         qWarning() << "the recordType is Error! set default recordtype webm";
@@ -362,12 +386,14 @@ bool GstRecordX::createPipeline(QStringList arguments)
         qCritical() << "gstreamer pares error: " << error->code << " , " << error->message;
         return false;
     }
+    qCInfo(dsrApp) << "GStreamer pipeline created successfully";
     return true;
 }
 
 //根据传入的参数获取，音频管道创建命令
 QString GstRecordX::getAudioPipeline(const QString &audioDevName, const QString &audioType, const QString &arg)
 {
+    qCDebug(dsrApp) << "Creating audio pipeline for" << audioType << "device:" << audioDevName;
     QString result = "";
     //判断设备名称是否为空，为空不会生成管道命令
     if (audioDevName.isEmpty()) {
@@ -380,8 +406,10 @@ QString GstRecordX::getAudioPipeline(const QString &audioDevName, const QString
         //根据传入的参数，生成不同的处理器（音频混流器或复用器）
         if (arg == "mix") {
             result += " ! queue ! mix.";
+            qCDebug(dsrApp) << "Audio pipeline configured for mixing";
         } else if (arg == "mux") {
             result += " ! vorbisenc ! queue ! mux.";
+            qCDebug(dsrApp) << "Audio pipeline configured for muxing";
         } else {
             qCritical() << "Error: Parameter that does not exist!";
             result = "";
@@ -393,6 +421,7 @@ QString GstRecordX::getAudioPipeline(const QString &audioDevName, const QString
 //停止管道，x11和wayland可共用
 void GstRecordX::stopPipeline()
 {
+    qCInfo(dsrApp) << "Stopping GStreamer pipeline";
     bool a = gstInterface::m_gst_element_send_event(m_pipeline, gstInterface::m_gst_event_new_eos());
     Q_UNUSED(a);
 
@@ -403,18 +432,23 @@ void GstRecordX::stopPipeline()
     GstStateChangeReturn ret ;
     Q_UNUSED(ret);
     ret = gstInterface::m_gst_element_set_state(m_pipeline, GST_STATE_PAUSED);
+    qCDebug(dsrApp) << "Pipeline state set to PAUSED";
     Q_UNUSED(ret);
     ret = gstInterface::m_gst_element_set_state(m_pipeline, GST_STATE_READY);
+    qCDebug(dsrApp) << "Pipeline state set to READY";
     Q_UNUSED(ret);
     ret = gstInterface::m_gst_element_set_state(m_pipeline, GST_STATE_NULL);
+    qCDebug(dsrApp) << "Pipeline state set to NULL";
     Q_UNUSED(ret);
     gstInterface::m_gst_object_unref(m_pipeline);
+    qCInfo(dsrApp) << "Pipeline stopped and cleaned up";
 }
 
 
 //格式化输出gstreamer命令
 void GstRecordX::pipelineStructuredOutput(QString pipeline)
 {
+    qCDebug(dsrApp) << "Formatting GStreamer pipeline command";
     QString string;
     QString nl;
     nl = "\\";
