@@ -1,5 +1,5 @@
 // Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -30,7 +30,7 @@ void MainToolWidget::initMainToolWidget()
     connect(m_saveButton, SIGNAL(clicked()), this, SIGNAL(signalSaveButtonClicked()));
 
     QHBoxLayout *hLayout = new QHBoxLayout(this);
-    hLayout->setMargin(0);
+    hLayout->setContentsMargins(0, 0, 0, 0);
     hLayout->addWidget(m_closeButton, 0, Qt::AlignCenter);
     hLayout->addWidget(m_saveButton, 0, Qt::AlignCenter);
     this->setLayout(hLayout);
