@@ -12,6 +12,7 @@
 #include <QThread>
 #include <QMutexLocker>
 #include "recordadmin.h"
+#include "../utils/log.h"
 
 CAVInputStream::CAVInputStream(WaylandIntegration::WaylandIntegrationPrivate *context):
     m_context(context)
@@ -61,10 +62,12 @@ void CAVInputStream::setSysAudioRecord(bool bRecord)
 
 bool CAVInputStream::openInputStream()
 {
+    qCInfo(dsrApp) << "Opening input streams";
     //打开系统音频输入流，
     bool bSysAudio = openSysStream();
     //此处的逻辑：当外部选择需要录制系统音（即m_bSysAudio为false），但是系统音频的输出流打开失败时，内部会将可以录制改为不可录制
     if (bSysAudio != m_bSysAudio) {
+        qCWarning(dsrApp) << "System audio stream open failure, changing m_bSysAudio from" << m_bSysAudio << "to" << bSysAudio;
         qWarning() << "sys audio stream open failure! " << "m_bSysAudio : " << m_bSysAudio << " to m_bSysAudio: " << bSysAudio;
         m_bSysAudio = bSysAudio;
     }
@@ -72,11 +75,13 @@ bool CAVInputStream::openInputStream()
     bool bMicAudio = openMicStream();
     //此处的逻辑：录制视频时选择需要录制麦克风音频，但是麦克风音频的输入流打开失败时，内部会将可以录制改为不可录制
     if (bMicAudio != m_bMicAudio) {
+        qCWarning(dsrApp) << "Microphone audio stream open failure, changing m_bMicAudio from" << m_bMicAudio << "to" << bMicAudio;
         qWarning() << "sys audio stream open failure! " << "m_bMicAudio : " << m_bMicAudio << " to m_bMicAudio: " << bMicAudio;
         m_bMicAudio = bMicAudio;
     }
     //只有外部选择了系统音频、麦克风音频及打开系统音频输出流成功、打开麦克风音频输入流成功的情况下才录制混音
     if (bSysAudio && bMicAudio) {
+        qCInfo(dsrApp) << "Both system and microphone audio streams opened successfully, enabling audio mixing";
         m_bMix = true;
     }
     return true;
@@ -85,6 +90,7 @@ bool CAVInputStream::openInputStream()
 //开麦克风音频输入流 注：录屏时不要求录制麦克风时，则此方法默认返回false
 bool CAVInputStream::openMicStream()
 {
+    qCInfo(dsrApp) << "Opening microphone audio stream";
     AVDictionary *device_param = nullptr;
     m_pAudioInputFormat = avlibInterface::m_av_find_input_format("pulse"); //alsa
     assert(m_pAudioInputFormat != nullptr);
@@ -126,6 +132,7 @@ bool CAVInputStream::openMicStream()
         avlibInterface::m_av_dump_format(m_pMicAudioFormatContext, 0, "default", 0);
         return true;
     } else {
+        qCDebug(dsrApp) << "Microphone recording not requested, skipping";
         return false;
     }
 }
@@ -133,6 +140,7 @@ bool CAVInputStream::openMicStream()
 //打开系统音频输入流 注：录屏时不要求录制系统音时，则此方法默认返回false
 bool CAVInputStream::openSysStream()
 {
+    qCInfo(dsrApp) << "Opening system audio stream";
     AVDictionary *device_param = nullptr;
     m_pAudioCardInputFormat = avlibInterface::m_av_find_input_format("pulse"); //alsa
     assert(m_pAudioCardInputFormat != nullptr);
@@ -168,27 +176,34 @@ bool CAVInputStream::openSysStream()
         }
         /* print Video device information*/
         avlibInterface::m_av_dump_format(m_pSysAudioFormatContext, 0, m_sysDeviceName.toLatin1(), 0);
+        qCInfo(dsrApp) << "System audio stream opened successfully";
         return true;
     } else {
+        qCDebug(dsrApp) << "System audio recording not requested, skipping";
         return false;
     }
 }
 
 bool CAVInputStream::audioCapture()
 {
+    qCInfo(dsrApp) << "Starting audio capture";
     m_start_time = avlibInterface::m_av_gettime();
     if (m_bMix) {
+        qCDebug(dsrApp) << "Creating audio mixing threads";
         pthread_create(&m_hMicAudioThread, nullptr, captureMicToMixAudioThreadFunc, static_cast<void *>(this));
         pthread_create(&m_hSysAudioThread, nullptr, captureSysToMixAudioThreadFunc, static_cast<void *>(this));
         pthread_create(&m_hMixThread, nullptr, writeMixThreadFunc, static_cast<void *>(this));
     } else {
         if (m_bMicAudio) {
+            qCDebug(dsrApp) << "Creating microphone audio capture thread";
             pthread_create(&m_hMicAudioThread, nullptr, captureMicAudioThreadFunc, static_cast<void *>(this));
         }
         if (m_bSysAudio) {
+            qCDebug(dsrApp) << "Creating system audio capture thread";
             pthread_create(&m_hSysAudioThread, nullptr, captureSysAudioThreadFunc, static_cast<void *>(this));
         }
     }
+    qCInfo(dsrApp) << "Audio capture started successfully";
     return true;
 }
 
@@ -310,15 +325,20 @@ void CAVInputStream::setbRunThread(bool bRunThread)
 
 void  CAVInputStream::onsFinisheStream()
 {
+    qCInfo(dsrApp) << "Finishing audio streams";
     if (m_hMixThread) {
+        qCDebug(dsrApp) << "Clearing mix thread handle";
         m_hMixThread = 0;
     }
     if (m_hMicAudioThread) {
+        qCDebug(dsrApp) << "Clearing microphone audio thread handle";
         m_hMicAudioThread = 0;
     }
     if (m_hSysAudioThread) {
+        qCDebug(dsrApp) << "Clearing system audio thread handle";
         m_hSysAudioThread = 0;
     }
+    qCInfo(dsrApp) << "Audio streams finished";
 }
 
 void *CAVInputStream::writeMixThreadFunc(void *param)
@@ -330,10 +350,11 @@ void *CAVInputStream::writeMixThreadFunc(void *param)
 
 void CAVInputStream::writMixAudio()
 {
-    //    while ((bWriteMix() || m_context->m_recordAdmin->m_pOutputStream->isNotAudioFifoEmty()) && m_bMix) {
+    qCDebug(dsrApp) << "Starting mixed audio write loop";
     while (bWriteMix() && m_bMix) {
         m_context->m_recordAdmin->m_pOutputStream->writeMixAudio();
     }
+    qCDebug(dsrApp) << "Mixed audio write loop ended";
 }
 
 void *CAVInputStream::captureMicAudioThreadFunc(void *param)
@@ -353,13 +374,16 @@ void *CAVInputStream::captureMicToMixAudioThreadFunc(void *param)
 //ReadAudioPackets + ReadVideoPackets
 int CAVInputStream::readMicAudioPacket()
 {
+    qCInfo(dsrApp) << "Starting microphone audio packet reading";
     int got_frame_ptr = 0;
     //start decode and encode
     while (bRunThread()) {
         int ret;
         AVFrame *inputFrame = avlibInterface::m_av_frame_alloc();
-        if (!inputFrame)
+        if (!inputFrame) {
+            qCCritical(dsrApp) << "Failed to allocate input frame";
             return AVERROR(ENOMEM);
+        }
         /** Decode one frame worth of audio samples. */
         /** Packet used for temporary storage. */
         AVPacket inputPacket;
@@ -370,8 +394,10 @@ int CAVInputStream::readMicAudioPacket()
         if ((ret = avlibInterface::m_av_read_frame(m_pMicAudioFormatContext, &inputPacket)) < 0) {
             /** If we are at the end of the file, flush the decoder below. */
             if (ret == AVERROR_EOF) {
+                qCInfo(dsrApp) << "Reached end of microphone stream";
                 setbRunThread(false);
             } else {
+                qCDebug(dsrApp) << "Failed to read frame, continuing";
                 avlibInterface::m_av_packet_unref(&inputPacket);
                 avlibInterface::m_av_frame_free(&inputFrame);
                 continue;
@@ -379,6 +405,7 @@ int CAVInputStream::readMicAudioPacket()
         }
         //AVPacket -> AVFrame
         if ((ret = avlibInterface::m_avcodec_decode_audio4(m_pMicAudioFormatContext->streams[m_micAudioindex]->codec, inputFrame, &got_frame_ptr, &inputPacket)) < 0) {
+            qCCritical(dsrApp) << "Could not decode audio frame";
             printf("Could not decode audio frame\n");
             avlibInterface::m_av_packet_unref(&inputPacket);
             avlibInterface::m_av_frame_free(&inputFrame);
@@ -387,31 +414,38 @@ int CAVInputStream::readMicAudioPacket()
         avlibInterface::m_av_packet_unref(&inputPacket);
         /** If there is decoded data, convert and store it */
         if (got_frame_ptr) {
+            qCDebug(dsrApp) << "Writing decoded microphone audio frame";
             m_context->m_recordAdmin->m_pOutputStream->writeMicAudioFrame(m_pMicAudioFormatContext->streams[m_micAudioindex], inputFrame, avlibInterface::m_av_gettime() - m_start_time);
         }
         avlibInterface::m_av_frame_free(&inputFrame);
         fflush(stdout);
     }// -- while end
     if (nullptr != m_pMicAudioFormatContext) {
+        qCDebug(dsrApp) << "Closing microphone audio format context";
         avlibInterface::m_avformat_close_input(&m_pMicAudioFormatContext);
     }
     if (nullptr != m_pMicAudioFormatContext) {
+        qCDebug(dsrApp) << "Freeing microphone audio format context";
         avlibInterface::m_avformat_free_context(m_pMicAudioFormatContext);
         m_pMicAudioFormatContext = nullptr;
     }
     m_micAudioindex = -1;
+    qCInfo(dsrApp) << "Microphone audio packet reading completed";
     return 0;
 }
 
 int CAVInputStream::readMicToMixAudioPacket()
 {
+    qCInfo(dsrApp) << "Starting microphone to mix audio packet reading";
     int got_frame_ptr = 0;
     //start decode and encode
     while (bRunThread()) {
         int ret;
         AVFrame *inputFrame = avlibInterface::m_av_frame_alloc();
-        if (!inputFrame)
+        if (!inputFrame) {
+            qCCritical(dsrApp) << "Failed to allocate input frame";
             return AVERROR(ENOMEM);
+        }
         /** Decode one frame worth of audio samples.解码一帧值的音频样本。 */
         /** Packet used for temporary storage. 临时存储用的小包。*/
         AVPacket inputPacket;
@@ -422,8 +456,10 @@ int CAVInputStream::readMicToMixAudioPacket()
         if ((ret = avlibInterface::m_av_read_frame(m_pMicAudioFormatContext, &inputPacket)) < 0) {
             /** If we are at the end of the file, flush the decoder below. 如果我们在文件的末尾，刷新下面的解码器。*/
             if (ret == AVERROR_EOF) {
+                qCInfo(dsrApp) << "Reached end of microphone stream";
                 setbRunThread(false);
             } else {
+                qCDebug(dsrApp) << "Failed to read frame, continuing";
                 avlibInterface::m_av_packet_unref(&inputPacket);
                 avlibInterface::m_av_frame_free(&inputFrame);
                 continue;
@@ -431,6 +467,7 @@ int CAVInputStream::readMicToMixAudioPacket()
         }
         //AVPacket -> AVFrame
         if ((ret = avlibInterface::m_avcodec_decode_audio4(m_pMicAudioFormatContext->streams[m_micAudioindex]->codec, inputFrame, &got_frame_ptr, &inputPacket)) < 0) {
+            qCCritical(dsrApp) << "Could not decode audio frame";
             printf("Could not decode audio frame\n");
             avlibInterface::m_av_packet_unref(&inputPacket);
             avlibInterface::m_av_frame_free(&inputFrame);
@@ -439,19 +476,23 @@ int CAVInputStream::readMicToMixAudioPacket()
         avlibInterface::m_av_packet_unref(&inputPacket);
         /** If there is decoded data, convert and store it 如果有解码的数据，转换并存储它*/
         if (got_frame_ptr) {
+            qCDebug(dsrApp) << "Writing decoded microphone frame to mix";
             m_context->m_recordAdmin->m_pOutputStream->writeMicToMixAudioFrame(m_pMicAudioFormatContext->streams[m_micAudioindex], inputFrame, avlibInterface::m_av_gettime() - m_start_time);
         }
         avlibInterface::m_av_frame_free(&inputFrame);
         fflush(stdout);
     }// -- while end
     if (nullptr != m_pMicAudioFormatContext) {
+        qCDebug(dsrApp) << "Closing microphone audio format context";
         avlibInterface::m_avformat_close_input(&m_pMicAudioFormatContext);
     }
     if (nullptr != m_pMicAudioFormatContext) {
+        qCDebug(dsrApp) << "Freeing microphone audio format context";
         avlibInterface::m_avformat_free_context(m_pMicAudioFormatContext);
         m_pMicAudioFormatContext = nullptr;
     }
     m_micAudioindex = -1;
+    qCInfo(dsrApp) << "Microphone to mix audio packet reading completed";
     return 0;
 }
 
@@ -472,14 +513,18 @@ void *CAVInputStream::captureSysToMixAudioThreadFunc(void *param)
 //ReadAudioPackets + ReadVideoPackets
 int CAVInputStream::readSysAudioPacket()
 {
-    if (!m_bSysAudio)
+    if (!m_bSysAudio) {
+        qCDebug(dsrApp) << "System audio recording not enabled, skipping";
         return 1;
+    }
+    qCInfo(dsrApp) << "Starting system audio packet reading";
     int got_frame_ptr = 0;
     //start decode and encode
     while (bRunThread()) {
         int ret;
         AVFrame *input_frame = avlibInterface::m_av_frame_alloc();
         if (!input_frame) {
+            qCCritical(dsrApp) << "Failed to allocate input frame";
             return AVERROR(ENOMEM);
         }
         AVPacket inputPacket;
@@ -490,8 +535,10 @@ int CAVInputStream::readSysAudioPacket()
         if ((ret = avlibInterface::m_av_read_frame(m_pSysAudioFormatContext, &inputPacket)) < 0) {
             /** If we are at the end of the file, flush the decoder below. */
             if (ret == AVERROR_EOF) {
+                qCInfo(dsrApp) << "Reached end of system audio stream";
                 setbRunThread(false);
             } else {
+                qCDebug(dsrApp) << "Failed to read frame, continuing";
                 avlibInterface::m_av_packet_unref(&inputPacket);
                 avlibInterface::m_av_frame_free(&input_frame);
                 continue;
@@ -506,28 +553,34 @@ int CAVInputStream::readSysAudioPacket()
         avlibInterface::m_av_packet_unref(&inputPacket);
         /** If there is decoded data, convert and store it */
         if (got_frame_ptr) {
+            qCDebug(dsrApp) << "Writing decoded system audio frame";
             m_context->m_recordAdmin->m_pOutputStream->writeSysAudioFrame(m_pSysAudioFormatContext->streams[m_sysAudioindex], input_frame, avlibInterface::m_av_gettime() - m_start_time);
         }
         avlibInterface::m_av_frame_free(&input_frame);
     }// -- while end
     if (nullptr != m_pSysAudioFormatContext) {
+        qCDebug(dsrApp) << "Closing system audio format context";
         avlibInterface::m_avformat_close_input(&m_pSysAudioFormatContext);
     }
     if (nullptr != m_pSysAudioFormatContext) {
+        qCDebug(dsrApp) << "Freeing system audio format context";
         avlibInterface::m_avformat_free_context(m_pSysAudioFormatContext);
         m_pSysAudioFormatContext = nullptr;
     }
     m_sysAudioindex = -1;
+    qCInfo(dsrApp) << "System audio packet reading completed";
     return 0;
 }
 
 int CAVInputStream::readSysToMixAudioPacket()
 {
+    qCInfo(dsrApp) << "Starting system to mix audio packet reading";
     int got_frame_ptr = 0;
     while (bRunThread()) {
         int ret;
         AVFrame *inputFrame = avlibInterface::m_av_frame_alloc();
         if (!inputFrame) {
+            qCCritical(dsrApp) << "Failed to allocate input frame";
             return AVERROR(ENOMEM);
         }
         AVPacket inputPacket;
@@ -538,14 +591,17 @@ int CAVInputStream::readSysToMixAudioPacket()
         if ((ret = avlibInterface::m_av_read_frame(m_pSysAudioFormatContext, &inputPacket)) < 0) {
             /** If we are at the end of the file, flush the decoder below. */
             if (ret == AVERROR_EOF) {
+                qCInfo(dsrApp) << "Reached end of system audio stream";
                 setbRunThread(false);
             } else {
+                qCDebug(dsrApp) << "Failed to read frame, continuing";
                 avlibInterface::m_av_packet_unref(&inputPacket);
                 avlibInterface::m_av_frame_free(&inputFrame);
                 continue;
             }
         }
         if ((ret = avlibInterface::m_avcodec_decode_audio4(m_pSysAudioFormatContext->streams[m_sysAudioindex]->codec, inputFrame, &got_frame_ptr, &inputPacket)) < 0) {
+            qCCritical(dsrApp) << "Could not decode audio frame";
             printf("Could not decode audio frame\n");
             avlibInterface::m_av_packet_unref(&inputPacket);
             avlibInterface::m_av_frame_free(&inputFrame);
@@ -553,56 +609,69 @@ int CAVInputStream::readSysToMixAudioPacket()
         }
         avlibInterface::m_av_packet_unref(&inputPacket);
         if (got_frame_ptr) {
+            qCDebug(dsrApp) << "Writing decoded system frame to mix";
             m_context->m_recordAdmin->m_pOutputStream->writeSysToMixAudioFrame(m_pSysAudioFormatContext->streams[m_sysAudioindex], inputFrame, avlibInterface::m_av_gettime() - m_start_time);
         }
         avlibInterface::m_av_frame_free(&inputFrame);
     }// -- while end
     if (nullptr != m_pSysAudioFormatContext) {
+        qCDebug(dsrApp) << "Closing system audio format context";
         avlibInterface::m_avformat_close_input(&m_pSysAudioFormatContext);
     }
     if (nullptr != m_pSysAudioFormatContext) {
+        qCDebug(dsrApp) << "Freeing system audio format context";
         avlibInterface::m_avformat_free_context(m_pSysAudioFormatContext);
         m_pSysAudioFormatContext = nullptr;
     }
     m_sysAudioindex = -1;
+    qCInfo(dsrApp) << "System to mix audio packet reading completed";
     return 0;
 }
 
 bool CAVInputStream::GetVideoInputInfo(int &width, int &height, int &frame_rate, AVPixelFormat &pixFmt)
 {
+    qCDebug(dsrApp) << "Getting video input information";
     width = m_screenDW - m_left - m_right;
     height = m_screenDH - m_top - m_bottom;
     pixFmt = m_ipix_fmt;
     frame_rate = m_fps;
+    qCDebug(dsrApp) << "Video input info - Width:" << width << "Height:" << height << "Frame rate:" << frame_rate;
     return true;
 }
 
-bool  CAVInputStream::GetAudioInputInfo(AVSampleFormat &sample_fmt, int &sample_rate, int &channels, int &layout)
+bool CAVInputStream::GetAudioInputInfo(AVSampleFormat &sample_fmt, int &sample_rate, int &channels, int &layout)
 {
+    qCDebug(dsrApp) << "Getting audio input information";
     if (m_micAudioindex != -1) {
         sample_fmt = m_pMicAudioFormatContext->streams[m_micAudioindex]->codec->sample_fmt;
         sample_rate = m_pMicAudioFormatContext->streams[m_micAudioindex]->codec->sample_rate;
         channels = m_pMicAudioFormatContext->streams[m_micAudioindex]->codec->channels;
         layout = static_cast<int>(m_pMicAudioFormatContext->streams[m_micAudioindex]->codec->channel_layout);
+        qCDebug(dsrApp) << "Audio input info - Sample rate:" << sample_rate << "Channels:" << channels;
         return true;
     }
-
+    qCDebug(dsrApp) << "No audio input information available";
     return false;
 }
-bool  CAVInputStream::GetAudioSCardInputInfo(AVSampleFormat &sample_fmt, int &sample_rate, int &channels, int &layout)
+
+bool CAVInputStream::GetAudioSCardInputInfo(AVSampleFormat &sample_fmt, int &sample_rate, int &channels, int &layout)
 {
+    qCDebug(dsrApp) << "Getting system audio card input information";
     if (m_sysAudioindex != -1) {
         sample_fmt = m_pSysAudioFormatContext->streams[m_sysAudioindex]->codec->sample_fmt;
         sample_rate = m_pSysAudioFormatContext->streams[m_sysAudioindex]->codec->sample_rate;
         channels = m_pSysAudioFormatContext->streams[m_sysAudioindex]->codec->channels;
         layout = static_cast<int>(m_pSysAudioFormatContext->streams[m_sysAudioindex]->codec->channel_layout);
+        qCDebug(dsrApp) << "System audio input info - Sample rate:" << sample_rate << "Channels:" << channels;
         return true;
     }
+    qCDebug(dsrApp) << "No system audio input information available";
     return false;
 }
 
 QString CAVInputStream::currentAudioChannel()
 {
+    qCDebug(dsrApp) << "Getting current audio channel";
     QString command = QString("pacmd list-sources");
     QProcess process;
     process.start(command);
@@ -624,5 +693,6 @@ QString CAVInputStream::currentAudioChannel()
     }
 
     process.close();
+    qCDebug(dsrApp) << "Current audio channel:" << targetLine;
     return targetLine;
 }
