@@ -1,16 +1,15 @@
 // Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "../utils/calculaterect.h"
 #include "../utils/configsettings.h"
 #include "../utils/tempfile.h"
+#include "../utils/shapesutils.h"
 #include "shapeswidget.h"
 #include "../utils.h"
-#ifdef KF5_WAYLAND_FLAGE_ON
-#include "../utils/waylandmousesimulator.h"
-#endif
+#include "../utils/log.h"
 
 #include <QApplication>
 #include <QPainter>
@@ -90,20 +89,22 @@ ShapesWidget::~ShapesWidget()
 void ShapesWidget::updateSelectedShape(const QString &group,
                                        const QString &key, int index)
 {
-//        qDebug() << ">>>>> function: " << __func__ << ", line: " << __LINE__
-//                 << ", group: " << group
-//                 << ", key: " << key
-//                 << ", index: " << index
-//                 << ", m_selectedIndex" << m_selectedIndex;
-    if (m_isSelectedText) { //修复在截图区域，选中的文本框，字体会自动变颜色
+    qCDebug(dsrApp) << "Updating selected shape - group:" << group << "key:" << key << "index:" << index;
+    
+    if (m_isSelectedText) {
+        qCDebug(dsrApp) << "Skipping update for selected text";
         m_isSelectedText = false;
         return;
     }
+    
     if (group == m_currentShape.type && key == "color_index") {
         m_penColor = BaseUtils::colorIndexOf(index);
+        qCDebug(dsrApp) << "Updated pen color to:" << m_penColor;
     }
 
     if (m_selectedIndex != -1 && m_selectedOrder != -1 && m_selectedOrder < m_shapes.length()) {
+        qCDebug(dsrApp) << "Updating shape properties for selected shape at order:" << m_selectedOrder;
+        
         if ((m_selectedShape.type == "arrow" || m_selectedShape.type == "line") && key != "color_index") {
             m_selectedShape.lineWidth = LINEWIDTH(index);
         } else if (m_selectedShape.type == group && key == "line_width") {
@@ -111,6 +112,7 @@ void ShapesWidget::updateSelectedShape(const QString &group,
         } else if (group == "text" && m_selectedShape.type == group && key == "color_index") {
             int tmpIndex = m_shapes[m_selectedOrder].index;
             if (m_editMap.contains(tmpIndex)) {
+                m_selectedShape.colorIndex = index;
                 m_editMap.value(tmpIndex)->setColor(BaseUtils::colorIndexOf(index));
                 m_editMap.value(tmpIndex)->update();
             }
@@ -137,6 +139,7 @@ void ShapesWidget::updateSelectedShape(const QString &group,
 
         if (m_selectedOrder < m_shapes.length()) {
             m_shapes[m_selectedOrder] = m_selectedShape;
+            qCDebug(dsrApp) << "Shape updated at order:" << m_selectedOrder;
         }
         update();
     }
@@ -160,6 +163,8 @@ void ShapesWidget::setCurrentShape(QString shapeType)
 
 void ShapesWidget::clearSelected()
 {
+    qCDebug(dsrApp) << "Clearing selected shape";
+    
     for (int j = 0; j < m_selectedShape.mainPoints.length(); j++) {
         m_selectedShape.mainPoints[j] = QPointF(0, 0);
         m_hoveredShape.mainPoints[j] = QPointF(0, 0);
@@ -174,6 +179,8 @@ void ShapesWidget::clearSelected()
 
 void ShapesWidget::setAllTextEditReadOnly()
 {
+    qCDebug(dsrApp) << "Setting all text edits to read-only";
+    
     QMap<int, TextEdit *>::iterator i = m_editMap.begin();
     while (i != m_editMap.end()) {
         i.value()->setReadOnly(true);
@@ -192,6 +199,8 @@ void ShapesWidget::setAllTextEditReadOnly()
 
 void ShapesWidget::setNoChangedTextEditRemove()
 {
+    qCDebug(dsrApp) << "Removing unchanged text edits";
+    
     if (m_shapes.length() == 0) {
         return;
     }
@@ -200,6 +209,7 @@ void ShapesWidget::setNoChangedTextEditRemove()
             int t_tempIndex = m_shapes[i].index;
             if (m_editMap.value(t_tempIndex)->document()->toPlainText() == QString(tr("Input text here"))
                     || m_editMap.value(t_tempIndex)->document()->toPlainText().isEmpty()) {
+                qCDebug(dsrApp) << "Removing empty text edit at index:" << t_tempIndex;
                 m_shapes.removeAt(i);
                 m_editMap.value(t_tempIndex)->clear();
                 m_editMap.remove(t_tempIndex);
@@ -211,6 +221,7 @@ void ShapesWidget::setNoChangedTextEditRemove()
 
     }
     if (m_shapes.length() == 0) {
+        qCDebug(dsrApp) << "No shapes remaining, disabling undo";
         emit setShapesUndo(false);
     }
 
@@ -229,6 +240,7 @@ void ShapesWidget::saveActionTriggered()
 //点击某个形状
 bool ShapesWidget::clickedOnShapes(QPointF pos)
 {
+    qCDebug(dsrApp) << "Checking for shape click at position:" << pos;
     bool onShapes = false;
     m_selectedOrder = -1;
     //    qDebug() << ">>>>> function: " << __func__ << ", line: " << __LINE__
@@ -239,12 +251,14 @@ bool ShapesWidget::clickedOnShapes(QPointF pos)
         bool currentOnShape = false;
         if (m_shapes[i].type == "rectangle") {
             if (clickedOnRect(m_shapes[i].mainPoints, pos, false)) {
+                qCDebug(dsrApp) << "Clicked on rectangle at index:" << i;
                 currentOnShape = true;
                 emit shapeClicked("rect");
             }
         }
         if (m_shapes[i].type == "oval") {
             if (clickedOnEllipse(m_shapes[i].mainPoints, pos, false)) {
+                qCDebug(dsrApp) << "Clicked on oval at index:" << i;
                 currentOnShape = true;
                 emit shapeClicked("circ");
             }
@@ -797,24 +811,52 @@ bool ShapesWidget::hoverOnArrow(QList<QPointF> points, QPointF pos)
 {
     if (points.length() != 2)
         return false;
+    bool result = false;
+//    QPointF t_rotatepos;
 
-    if (pointOnLine(points[0], points[1], pos)) {
+//    qreal t_minx = qMin(points[1].x(), points[0].x());
+//    qreal t_miny = qMin(points[1].y(), points[0].y());
+//    int t_height = qAbs(points[1].y() - points[0].y());
+//    int t_width = qAbs(points[1].x() - points[0].x());
+
+//    t_rotatepos.setX(t_minx + t_width / 2 - 5);
+//    t_rotatepos.setY(t_miny + t_height / 2 - 35);
+
+    //第一个点的偏移量
+    qreal firstPointPadX = std::abs(pos.x() - points[0].x());
+    qreal firstPointPadY = std::abs(pos.y() - points[0].y());
+    //第二个点的偏移量
+    qreal secondPointPadX = std::abs(pos.x() - points[1].x());
+    qreal secondPointPadY = std::abs(pos.y() - points[1].y());
+    //端点的偏移最大值
+    int pointPadding = 4;
+    if (pointOnLine(points[0], points[1], pos) &&
+            ((firstPointPadX > pointPadding || firstPointPadY > pointPadding)  &&
+             (secondPointPadX > pointPadding  || secondPointPadY > pointPadding))) {
         m_resizeDirection = Moving;
-        return true;
+        m_clickedKey = Unknow;
+        result = true;
     } else if (m_selectedIndex != -1 && m_selectedIndex == m_hoveredIndex
-               && pointClickIn(points[0], pos)) {
+               && pointClickIn(points[0], pos) && firstPointPadX <= pointPadding && firstPointPadY <= pointPadding) {
         m_clickedKey = First;
         m_resizeDirection = Rotate;
-        return true;
+        result = true;
     } else if (m_selectedIndex != -1 && m_selectedIndex == m_hoveredIndex
-               && pointClickIn(points[1], pos)) {
+               && pointClickIn(points[1], pos) && secondPointPadX <= pointPadding && secondPointPadY <= pointPadding) {
         m_clickedKey =   Second;
         m_resizeDirection = Rotate;
-        return true;
-    } else {
+        result = true;
+    } /*else if ( m_selectedIndex != -1 && m_selectedIndex == m_hoveredIndex
+                && pointClickIn(t_rotatepos, pos)) {
+        m_clickedKey =  Third;
+        m_resizeDirection = Rotate;
+        return true;*/
+//    }
+    else {
         m_resizeDirection = Outting;
-        return false;
+        result = false;
     }
+    return result;
 }
 
 bool ShapesWidget::hoverOnLine(FourPoints mainPoints, QList<QPointF> points,
@@ -1837,6 +1879,19 @@ void ShapesWidget::paintText(QPainter &painter, FourPoints rectFPoints)
     }
 }
 
+void ShapesWidget::paintText(QPainter &painter, FourPoints rectFPoints, const QString &text, int fontsize)
+{
+    qDebug() << "fontsize: " << fontsize;
+    QFont font = painter.font() ;
+    font.setPixelSize(fontsize);
+    painter.setFont(font);
+    QRect rect(static_cast<int>(rectFPoints[0].x()),
+               static_cast<int>(rectFPoints[0].y()),
+               static_cast<int>(rectFPoints[3].x() - rectFPoints[0].x()),
+               static_cast<int>(rectFPoints[3].y() - rectFPoints[0].y()));
+    painter.drawText(rect, Qt::AlignLeft, text);
+}
+
 void ShapesWidget::paintEvent(QPaintEvent *)
 {
     QPainter painter(this);
