@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="it">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -25,6 +23,17 @@ o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione<
         <translation>Registrazione in corso</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Record</source>
+        <translation>Registrazione</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Screenshot</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -95,17 +104,21 @@ o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione<
         <source>Scrollshot</source>
         <translation>Screenshot a scorrimento</translation>
     </message>
-    <message>
-        <source>Open Folder</source>
-        <translation>Apri cartella</translation>
-    </message>
     <message>
         <source>Pin Screenshots</source>
         <translation>Blocca screenshot</translation>
     </message>
     <message>
         <source>deepin-screen-recorder</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Apri cartella</translation>
+    </message>
+    <message>
+        <source>Screenshot finished and copy to clipboard</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -134,22 +147,22 @@ o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione<
     <name>QuickPanelWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Screenshot</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Record</source>
-        <translation type="unfinished">Registrazione</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>RecordIconWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Screenshot</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished">Registrazione in corso</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -334,6 +347,10 @@ o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione<
         <source>Display shortcuts</source>
         <translation>Visualizza scorciatoie</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Suono</translation>
+    </message>
     <message>
         <source>Keystroke</source>
         <translation>Sequenza tasti</translation>
@@ -354,6 +371,10 @@ o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione<
         <source>Start/Recording</source>
         <translation>Avvia/Registra</translation>
     </message>
+    <message>
+        <source>Mouse</source>
+        <translation>Mouse</translation>
+    </message>
     <message>
         <source>Tools</source>
         <translation>Strumenti</translation>
@@ -370,26 +391,18 @@ o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione<
         <source>Pin screenshots</source>
         <translation>Blocca screenshot</translation>
     </message>
-    <message>
-        <source>Start scrollshot</source>
-        <translation>Avvia screenshot continuo</translation>
-    </message>
     <message>
         <source>Start OCR</source>
         <translation>Avvia OCR</translation>
     </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation>Avvia screenshot continuo</translation>
+    </message>
     <message>
         <source>Arrow</source>
         <translation>Freccia</translation>
     </message>
-    <message>
-        <source>Sound</source>
-        <translation>Suono</translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation>Mouse</translation>
-    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -402,7 +415,7 @@ o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione<
     <name>ShotStartRecordPlugin</name>
     <message>
         <source>Record</source>
-        <translation type="unfinished">Registrazione</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -410,40 +423,76 @@ o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione<
     <message>
         <source>Rectangle
 Press and hold Shift to draw a square</source>
-        <translation type="unfinished"></translation>
+        <translation>Rettangolo
+Tieni premuto Maiusc per disegnare un quadrato</translation>
     </message>
     <message>
         <source>Ellipse
 Press and hold Shift to draw a circle</source>
-        <translation type="unfinished"></translation>
+        <translation>Ellisse
+Tieni premuto Maiusc per disegnare un cerchio</translation>
     </message>
     <message>
         <source>Brush
 Press and hold Shift to draw a straight line</source>
-        <translation type="unfinished"></translation>
+        <translation>Spazzola
+Tieni premuto Maiusc per tracciare una linea retta</translation>
     </message>
     <message>
         <source>Adjust blur strength (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>Regola l&apos;intensità della sfocatura (scorri per regolarla)</translation>
     </message>
     <message>
         <source>Adjust brush size (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>Regola la dimensione del pennello (scorri per regolarla)</translation>
     </message>
     <message>
         <source>Adjust text size (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>Regola la dimensione testo (scorri per regolarla)</translation>
+    </message>
+</context>
+<context>
+    <name>StartTooltip</name>
+    <message>
+        <source>Click or drag to
+select the area to record</source>
+        <translation>Clicca o trascina
+seleziona l&apos;area da registrare</translation>
     </message>
 </context>
 <context>
     <name>SubToolWidget</name>
     <message>
-        <source>Microphone</source>
-        <translation>Microfono</translation>
+        <source>Show keystroke (K)</source>
+        <translation>Mostra sequenza di tasti (K)</translation>
     </message>
     <message>
-        <source>Options</source>
-        <translation>Opzioni</translation>
+        <source>Hide Keystroke (K)</source>
+        <translation>Nascondi sequenza di tasti (K)</translation>
+    </message>
+    <message>
+        <source>Show Keystroke (K)</source>
+        <translation>Mostra sequenza di tasti (K)</translation>
+    </message>
+    <message>
+        <source>Turn on camera (C)</source>
+        <translation>Attiva camera (C)</translation>
+    </message>
+    <message>
+        <source>Turn off camera (C)</source>
+        <translation>Disattiva camera (C)</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Screenshot</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Impostazioni</translation>
+    </message>
+    <message>
+        <source>Settings (F3)</source>
+        <translation>Impostazioni (F3)</translation>
     </message>
     <message>
         <source>Format:</source>
@@ -457,6 +506,14 @@ Press and hold Shift to draw a straight line</source>
         <source>MP4</source>
         <translation>MP4</translation>
     </message>
+    <message>
+        <source>MKV</source>
+        <translation>MKV</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
     <message>
         <source>FPS:</source>
         <translation>FPS:</translation>
@@ -481,6 +538,30 @@ Press and hold Shift to draw a straight line</source>
         <source>30 fps</source>
         <translation>30 fps</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Suono</translation>
+    </message>
+    <message>
+        <source>Microphone</source>
+        <translation>Microfono</translation>
+    </message>
+    <message>
+        <source>System audio</source>
+        <translation>Audio di sistema</translation>
+    </message>
+    <message>
+        <source>Options</source>
+        <translation>Opzioni</translation>
+    </message>
+    <message>
+        <source>Show pointer</source>
+        <translation>Mostra il puntatore</translation>
+    </message>
+    <message>
+        <source>Show click</source>
+        <translation>Mostra click</translation>
+    </message>
     <message>
         <source>Save to</source>
         <translation>Salva in</translation>
@@ -490,56 +571,36 @@ Press and hold Shift to draw a straight line</source>
         <translation>Desktop</translation>
     </message>
     <message>
-        <source>Pictures</source>
-        <translation>Immagini</translation>
+        <source>Videos</source>
+        <translation>Video</translation>
     </message>
     <message>
-        <source>Folder</source>
-        <translation>Cartella</translation>
+        <source>Rectangle (R)
+Press and hold Shift to draw a square</source>
+        <translation>Rettangolo (R)
+Tieni premuto Maiusc per disegnare un quadrato</translation>
     </message>
     <message>
-        <source>Format</source>
-        <translation>Formato</translation>
+        <source>Ellipse (O)
+Press and hold Shift to draw a circle</source>
+        <translation>Ellisse (O)
+Tieni premuto Maiusc per disegnare un cerchio</translation>
     </message>
     <message>
-        <source>PNG</source>
-        <translation>PNG</translation>
+        <source>Line (L)
+Press and hold Shift to draw a vertical or horizontal line</source>
+        <translation>Linea (L)
+Tieni premuto Maiusc per disegnare una linea verticale o orizzontale</translation>
     </message>
     <message>
-        <source>JPG</source>
-        <translation>JPG</translation>
+        <source>Arrow (X)
+Press and hold Shift to draw a vertical or horizontal arrow</source>
+        <translation>Freccia (X)
+Tieni premuto Maiusc per disegnare una freccia verticale o orizzontale</translation>
     </message>
     <message>
-        <source>BMP</source>
-        <translation>BMP</translation>
-    </message>
-    <message>
-        <source>MKV</source>
-        <translation>MKV</translation>
-    </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>Appunti</translation>
-    </message>
-    <message>
-        <source>Show pointer</source>
-        <translation>Mostra il puntatore</translation>
-    </message>
-    <message>
-        <source>Extract Text</source>
-        <translation>Estrai testo</translation>
-    </message>
-    <message>
-        <source>Show keystroke (K)</source>
-        <translation>Mostra sequenza di tasti (K)</translation>
-    </message>
-    <message>
-        <source>Settings</source>
-        <translation>Impostazioni</translation>
-    </message>
-    <message>
-        <source>Settings (F3)</source>
-        <translation>Impostazioni (F3)</translation>
+        <source>Pencil (P)</source>
+        <translation>Penna (P)</translation>
     </message>
     <message>
         <source>Blur (B)</source>
@@ -557,29 +618,53 @@ Press and hold Shift to draw a straight line</source>
         <source>Extract text (Alt+O）</source>
         <translation>Estrai testo (Alt+O）</translation>
     </message>
-    <message>
-        <source>Undo (Ctrl+Z)</source>
-        <translation>Annulla (Ctrl+Z)</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>Screenshot</translation>
-    </message>
     <message>
         <source>Pin screenshots (Alt+P）</source>
         <translation>Blocca screenshot (Alt+P)</translation>
     </message>
+    <message>
+        <source>Undo (Ctrl+Z)</source>
+        <translation>Annulla (Ctrl+Z)</translation>
+    </message>
     <message>
         <source>Record</source>
         <translation>Registrazione</translation>
     </message>
     <message>
-        <source>Pencil (P)</source>
-        <translation>Penna (P)</translation>
+        <source>Clipboard</source>
+        <translation>Appunti</translation>
     </message>
     <message>
-        <source>Turn on camera (C)</source>
-        <translation>Attiva camera (C)</translation>
+        <source>Pictures</source>
+        <translation>Immagini</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Cartella</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Seleziona un percorso di salvataggio</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Cambia il percorso di salvataggio</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Formato</translation>
+    </message>
+    <message>
+        <source>PNG</source>
+        <translation>PNG</translation>
+    </message>
+    <message>
+        <source>JPG</source>
+        <translation>JPG</translation>
+    </message>
+    <message>
+        <source>BMP</source>
+        <translation>BMP</translation>
     </message>
     <message>
         <source>Border Effects</source>
@@ -589,77 +674,21 @@ Press and hold Shift to draw a straight line</source>
         <source>None</source>
         <translation>Nessuno</translation>
     </message>
-    <message>
-        <source>Turn off camera (C)</source>
-        <translation>Disattiva camera (C)</translation>
-    </message>
-    <message>
-        <source>Hide Keystroke (K)</source>
-        <translation>Nascondi sequenza di tasti (K)</translation>
-    </message>
-    <message>
-        <source>Show Keystroke (K)</source>
-        <translation>Mostra sequenza di tasti (K)</translation>
-    </message>
-    <message>
-        <source>webm</source>
-        <translation>webm</translation>
-    </message>
-    <message>
-        <source>Videos</source>
-        <translation>Video</translation>
-    </message>
-    <message>
-        <source>Rectangle (R)
-Press and hold Shift to draw a square</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Ellipse (O)
-Press and hold Shift to draw a circle</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Line (L)
-Press and hold Shift to draw a vertical or horizontal line</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Arrow (X)
-Press and hold Shift to draw a vertical or horizontal arrow</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Shadow</source>
-        <translation type="unfinished"></translation>
+        <translation>Ombra</translation>
     </message>
     <message>
         <source>Border</source>
-        <translation type="unfinished"></translation>
+        <translation>Bordo</translation>
     </message>
     <message>
         <source>Device</source>
-        <translation type="unfinished"></translation>
+        <translation>Dispositivo</translation>
     </message>
     <message>
-        <source>Sound</source>
-        <translation>Suono</translation>
-    </message>
-    <message>
-        <source>System audio</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show click</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Change the path on save</source>
-        <translation type="unfinished"></translation>
+        <source>Extract Text</source>
+        <translation>Estrai testo</translation>
     </message>
 </context>
 <context>
@@ -691,4 +720,11 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>Esci</translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>VoiceRecordProcess</name>
+    <message>
+        <source>New recording</source>
+        <translation>Nuova registrazione</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
