@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="sq">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -25,6 +23,17 @@ klikoni ikonën e panelit, ose rishtypni shkurtoren</translation>
         <translation>Regjistrim</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Record</source>
+        <translation>Regjistroje</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Foto ekrani</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -93,11 +102,7 @@ klikoni ikonën e panelit, ose rishtypni shkurtoren</translation>
     </message>
     <message>
         <source>Scrollshot</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Open Folder</source>
-        <translation>Hapni Dosje</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Pin Screenshots</source>
@@ -105,7 +110,15 @@ klikoni ikonën e panelit, ose rishtypni shkurtoren</translation>
     </message>
     <message>
         <source>deepin-screen-recorder</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Hapni Dosje</translation>
+    </message>
+    <message>
+        <source>Screenshot finished and copy to clipboard</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -134,22 +147,22 @@ klikoni ikonën e panelit, ose rishtypni shkurtoren</translation>
     <name>QuickPanelWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Foto ekrani</translation>
+        <translation>Foto ekrani</translation>
     </message>
     <message>
         <source>Record</source>
-        <translation type="unfinished"></translation>
+        <translation>Regjistroje</translation>
     </message>
 </context>
 <context>
     <name>RecordIconWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Foto ekrani</translation>
+        <translation>Foto ekrani</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished">Regjistrim</translation>
+        <translation>Regjistrim</translation>
     </message>
 </context>
 <context>
@@ -206,11 +219,11 @@ klikoni ikonën e panelit, ose rishtypni shkurtoren</translation>
     </message>
     <message>
         <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
-        <translation type="unfinished"></translation>
+        <translation>Që të bëhet një foto ekrani, rrotulloni rrotëzën e miut tuaj, ose klikoni</translation>
     </message>
     <message>
         <source>Slow down the scrolling speed</source>
-        <translation type="unfinished"></translation>
+        <translation>Ngadalësoni shpejtësi rrotullimi</translation>
     </message>
     <message>
         <source>Invalid area, click to </source>
@@ -334,6 +347,10 @@ klikoni ikonën e panelit, ose rishtypni shkurtoren</translation>
         <source>Display shortcuts</source>
         <translation>Shfaq shkurtore</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Tingull</translation>
+    </message>
     <message>
         <source>Keystroke</source>
         <translation>Shtypje tastesh</translation>
@@ -354,6 +371,10 @@ klikoni ikonën e panelit, ose rishtypni shkurtoren</translation>
         <source>Start/Recording</source>
         <translation>Fillo/Regjistrim</translation>
     </message>
+    <message>
+        <source>Mouse</source>
+        <translation>Mi</translation>
+    </message>
     <message>
         <source>Tools</source>
         <translation>Mjete</translation>
@@ -364,32 +385,24 @@ klikoni ikonën e panelit, ose rishtypni shkurtoren</translation>
     </message>
     <message>
         <source>Scrollshot</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Pin screenshots</source>
         <translation>Fiksoni foto ekrani</translation>
     </message>
-    <message>
-        <source>Start scrollshot</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Start OCR</source>
         <translation>Nis OCR</translation>
     </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Arrow</source>
         <translation>Shigjetë</translation>
     </message>
-    <message>
-        <source>Sound</source>
-        <translation>Tingull</translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation>Mi</translation>
-    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -402,7 +415,7 @@ klikoni ikonën e panelit, ose rishtypni shkurtoren</translation>
     <name>ShotStartRecordPlugin</name>
     <message>
         <source>Record</source>
-        <translation type="unfinished"></translation>
+        <translation>Regjistroje</translation>
     </message>
 </context>
 <context>
@@ -438,15 +451,48 @@ Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një vijë e drejt
         <translation>Rregulloni madhësi teksti (Për ta rregulluar, rrëshqitni)</translation>
     </message>
 </context>
+<context>
+    <name>StartTooltip</name>
+    <message>
+        <source>Click or drag to
+select the area to record</source>
+        <translation>Që të përzgjidhet zona për
+regjistrim, klikoni, ose tërhiqeni</translation>
+    </message>
+</context>
 <context>
     <name>SubToolWidget</name>
     <message>
-        <source>Microphone</source>
-        <translation>Mikrofon</translation>
+        <source>Show keystroke (K)</source>
+        <translation>Shfaq varg tastesh për shtypje (K)</translation>
     </message>
     <message>
-        <source>Options</source>
-        <translation>Mundësi</translation>
+        <source>Hide Keystroke (K)</source>
+        <translation>Fshih Varg Tastesh Për Shtypje (K)</translation>
+    </message>
+    <message>
+        <source>Show Keystroke (K)</source>
+        <translation>Shfaq Varg Tastesh Për Shtypje (K)</translation>
+    </message>
+    <message>
+        <source>Turn on camera (C)</source>
+        <translation>Hapni kamerën (C)</translation>
+    </message>
+    <message>
+        <source>Turn off camera (C)</source>
+        <translation>Mbyllni kamerën (C)</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Foto ekrani</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Rregullime</translation>
+    </message>
+    <message>
+        <source>Settings (F3)</source>
+        <translation>Rregullime (F3)</translation>
     </message>
     <message>
         <source>Format:</source>
@@ -460,6 +506,14 @@ Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një vijë e drejt
         <source>MP4</source>
         <translation>MP4</translation>
     </message>
+    <message>
+        <source>MKV</source>
+        <translation>MKV</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
     <message>
         <source>FPS:</source>
         <translation>KPS:</translation>
@@ -484,6 +538,30 @@ Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një vijë e drejt
         <source>30 fps</source>
         <translation>30 kps</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Tingull</translation>
+    </message>
+    <message>
+        <source>Microphone</source>
+        <translation>Mikrofon</translation>
+    </message>
+    <message>
+        <source>System audio</source>
+        <translation>Audio sistemi</translation>
+    </message>
+    <message>
+        <source>Options</source>
+        <translation>Mundësi</translation>
+    </message>
+    <message>
+        <source>Show pointer</source>
+        <translation>Shfaq treguesin</translation>
+    </message>
+    <message>
+        <source>Show click</source>
+        <translation>Shfaq klikim</translation>
+    </message>
     <message>
         <source>Save to</source>
         <translation>Ruaje te</translation>
@@ -492,6 +570,70 @@ Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një vijë e drejt
         <source>Desktop</source>
         <translation>Desktop</translation>
     </message>
+    <message>
+        <source>Videos</source>
+        <translation>Video</translation>
+    </message>
+    <message>
+        <source>Rectangle (R)
+Press and hold Shift to draw a square</source>
+        <translation>Drejtkëndësh (R)
+Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një katror</translation>
+    </message>
+    <message>
+        <source>Ellipse (O)
+Press and hold Shift to draw a circle</source>
+        <translation>Elips (O)
+Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një rreth</translation>
+    </message>
+    <message>
+        <source>Line (L)
+Press and hold Shift to draw a vertical or horizontal line</source>
+        <translation>Vijë (L)
+Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një vijë vertikale ose horizontale</translation>
+    </message>
+    <message>
+        <source>Arrow (X)
+Press and hold Shift to draw a vertical or horizontal arrow</source>
+        <translation>Shigjetë (X)
+Shtypni dhe mbani të shtypur tastin Shift, që të vizatohet një shigjetë vertikale ose horizontale</translation>
+    </message>
+    <message>
+        <source>Pencil (P)</source>
+        <translation>Laps (P)</translation>
+    </message>
+    <message>
+        <source>Blur (B)</source>
+        <translation>Turbulloje (B)</translation>
+    </message>
+    <message>
+        <source>Text (T)</source>
+        <translation>Tekst (T)</translation>
+    </message>
+    <message>
+        <source>Scrollshot (Alt+I）</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Extract text (Alt+O）</source>
+        <translation>Përfto tekstin (Alt+O）</translation>
+    </message>
+    <message>
+        <source>Pin screenshots (Alt+P）</source>
+        <translation>Fiksoni foto ekrani (Alt+P）</translation>
+    </message>
+    <message>
+        <source>Undo (Ctrl+Z)</source>
+        <translation>Zhbëje (Ctrl+Z)</translation>
+    </message>
+    <message>
+        <source>Record</source>
+        <translation>Regjistro</translation>
+    </message>
+    <message>
+        <source>Clipboard</source>
+        <translation>E papastër</translation>
+    </message>
     <message>
         <source>Pictures</source>
         <translation>Foto</translation>
@@ -500,6 +642,14 @@ Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një vijë e drejt
         <source>Folder</source>
         <translation>Dosje</translation>
     </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Caktoni shteg gjatë ruajtjes</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Ndryshoni shtegun gjatë ruajtjes</translation>
+    </message>
     <message>
         <source>Format</source>
         <translation>Format</translation>
@@ -516,74 +666,6 @@ Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një vijë e drejt
         <source>BMP</source>
         <translation>BMP</translation>
     </message>
-    <message>
-        <source>MKV</source>
-        <translation>MKV</translation>
-    </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>E papastër</translation>
-    </message>
-    <message>
-        <source>Show pointer</source>
-        <translation>Shfaq treguesin</translation>
-    </message>
-    <message>
-        <source>Extract Text</source>
-        <translation>Përfto Tekst</translation>
-    </message>
-    <message>
-        <source>Show keystroke (K)</source>
-        <translation>Shfaq varg tastesh për shtypje (K)</translation>
-    </message>
-    <message>
-        <source>Settings</source>
-        <translation>Rregullime</translation>
-    </message>
-    <message>
-        <source>Settings (F3)</source>
-        <translation>Rregullime (F3)</translation>
-    </message>
-    <message>
-        <source>Blur (B)</source>
-        <translation>Turbulloje (B)</translation>
-    </message>
-    <message>
-        <source>Text (T)</source>
-        <translation>Tekst (T)</translation>
-    </message>
-    <message>
-        <source>Scrollshot (Alt+I）</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Extract text (Alt+O）</source>
-        <translation>Përfto tekstin (Alt+O）</translation>
-    </message>
-    <message>
-        <source>Undo (Ctrl+Z)</source>
-        <translation>Zhbëje (Ctrl+Z)</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>Foto ekrani</translation>
-    </message>
-    <message>
-        <source>Pin screenshots (Alt+P）</source>
-        <translation>Fiksoni foto ekrani (Alt+P）</translation>
-    </message>
-    <message>
-        <source>Record</source>
-        <translation>Regjistro</translation>
-    </message>
-    <message>
-        <source>Pencil (P)</source>
-        <translation>Laps (P)</translation>
-    </message>
-    <message>
-        <source>Turn on camera (C)</source>
-        <translation>Hapni kamerën (C)</translation>
-    </message>
     <message>
         <source>Border Effects</source>
         <translation>Efekte Anësh</translation>
@@ -592,81 +674,21 @@ Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një vijë e drejt
         <source>None</source>
         <translation>Asnjë</translation>
     </message>
-    <message>
-        <source>Turn off camera (C)</source>
-        <translation>Mbyllni kamerën (C)</translation>
-    </message>
-    <message>
-        <source>Hide Keystroke (K)</source>
-        <translation>Fshih Varg Tastesh Për Shtypje (K)</translation>
-    </message>
-    <message>
-        <source>Show Keystroke (K)</source>
-        <translation>Shfaq Varg Tastesh Për Shtypje (K)</translation>
-    </message>
-    <message>
-        <source>webm</source>
-        <translation>webm</translation>
-    </message>
-    <message>
-        <source>Videos</source>
-        <translation>Video</translation>
-    </message>
-    <message>
-        <source>Rectangle (R)
-Press and hold Shift to draw a square</source>
-        <translation>Drejtkëndësh (R)
-Shtypni dhe mbani të shtypur tastin Shift që të vizatoni një katror</translation>
-    </message>
-    <message>
-        <source>Ellipse (O)
-Press and hold Shift to draw a circle</source>
-        <translation>Elips (O)
-Shtypni dhe mbani të shtypur tastin Shift që të vizatoni një rreth</translation>
-    </message>
-    <message>
-        <source>Line (L)
-Press and hold Shift to draw a vertical or horizontal line</source>
-        <translation>Vijë (L)
-Shtypni dhe mbani të shtypur tastin Shift që të vizatoni një vijë vertikale ose horizontale</translation>
-    </message>
-    <message>
-        <source>Arrow (X)
-Press and hold Shift to draw a vertical or horizontal arrow</source>
-        <translation>Shigjetë (X)
-Shtypni dhe mbani të shtypur tastin Shift, që të vizatoni një shigjetë vertikale ose horizontale</translation>
-    </message>
     <message>
         <source>Shadow</source>
-        <translation type="unfinished"></translation>
+        <translation>Hije</translation>
     </message>
     <message>
         <source>Border</source>
-        <translation type="unfinished"></translation>
+        <translation>Anë</translation>
     </message>
     <message>
         <source>Device</source>
-        <translation type="unfinished"></translation>
+        <translation>Pajisje</translation>
     </message>
     <message>
-        <source>Sound</source>
-        <translation>Tingull</translation>
-    </message>
-    <message>
-        <source>System audio</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show click</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Change the path on save</source>
-        <translation type="unfinished"></translation>
+        <source>Extract Text</source>
+        <translation>Përfto Tekst</translation>
     </message>
 </context>
 <context>
@@ -698,4 +720,11 @@ Shtypni dhe mbani të shtypur tastin Shift, që të vizatoni një shigjetë vert
         <translation>Dil</translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>VoiceRecordProcess</name>
+    <message>
+        <source>New recording</source>
+        <translation>Regjistrim i ri</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
